gimp r27975 - in trunk: . app/core app/paint
- From: martinn svn gnome org
- To: svn-commits-list gnome org
- Subject: gimp r27975 - in trunk: . app/core app/paint
- Date: Sun, 1 Feb 2009 11:08:22 +0000 (UTC)
Author: martinn
Date: Sun Feb 1 11:08:22 2009
New Revision: 27975
URL: http://svn.gnome.org/viewvc/gimp?rev=27975&view=rev
Log:
Rename brush stuff with 'scale' to 'transform'.
Applied patch from Alexia Death that prepares brushes for
arbitrary transforms by renaming stuff with 'scale' to
'transform'. Takes us one step closer to fixing bug #520078.
* app/core/gimpbrush.[ch]
* app/core/gimpbrushgenerated.c
* app/paint/gimpbrushcore.[ch]
* app/paint/gimpsmudge.c
* app/core/gimpbrush-transform.[ch]: New names of
* app/core/gimpbrush-scale.[ch]
* app/core/Makefile.am: Update.
Added:
trunk/app/core/gimpbrush-transform.c
- copied, changed from r27974, /trunk/app/core/gimpbrush-scale.c
trunk/app/core/gimpbrush-transform.h
- copied, changed from r27974, /trunk/app/core/gimpbrush-scale.h
Removed:
trunk/app/core/gimpbrush-scale.c
trunk/app/core/gimpbrush-scale.h
Modified:
trunk/ChangeLog
trunk/app/core/Makefile.am
trunk/app/core/gimpbrush.c
trunk/app/core/gimpbrush.h
trunk/app/core/gimpbrushgenerated.c
trunk/app/paint/gimpbrushcore.c
trunk/app/paint/gimpbrushcore.h
trunk/app/paint/gimpsmudge.c
Modified: trunk/app/core/Makefile.am
==============================================================================
--- trunk/app/core/Makefile.am (original)
+++ trunk/app/core/Makefile.am Sun Feb 1 11:08:22 2009
@@ -54,8 +54,8 @@
gimpbrush-header.h \
gimpbrush-load.c \
gimpbrush-load.h \
- gimpbrush-scale.c \
- gimpbrush-scale.h \
+ gimpbrush-transform.c \
+ gimpbrush-transform.h \
gimpbrushclipboard.c \
gimpbrushclipboard.h \
gimpbrushgenerated.c \
Copied: trunk/app/core/gimpbrush-transform.c (from r27974, /trunk/app/core/gimpbrush-scale.c)
==============================================================================
--- /trunk/app/core/gimpbrush-scale.h (original)
+++ trunk/app/core/gimpbrush-transform.h Sun Feb 1 11:08:22 2009
@@ -23,14 +23,14 @@
/* virtual functions of GimpBrush, don't call directly */
-void gimp_brush_real_scale_size (GimpBrush *brush,
- gdouble scale,
- gint *scaled_width,
- gint *scaled_height);
-TempBuf * gimp_brush_real_scale_mask (GimpBrush *brush,
- gdouble scale);
-TempBuf * gimp_brush_real_scale_pixmap (GimpBrush *brush,
- gdouble scale);
+void gimp_brush_real_transform_size (GimpBrush *brush,
+ gdouble scale,
+ gint *scaled_width,
+ gint *scaled_height);
+TempBuf * gimp_brush_real_transform_mask (GimpBrush *brush,
+ gdouble scale);
+TempBuf * gimp_brush_real_transform_pixmap (GimpBrush *brush,
+ gdouble scale);
#endif /* __GIMP_BRUSH_SCALE_H__ */
Modified: trunk/app/core/gimpbrush.c
==============================================================================
--- trunk/app/core/gimpbrush.c (original)
+++ trunk/app/core/gimpbrush.c Sun Feb 1 11:08:22 2009
@@ -28,7 +28,7 @@
#include "gimpbrush.h"
#include "gimpbrush-load.h"
-#include "gimpbrush-scale.h"
+#include "gimpbrush-transform.h"
#include "gimpbrushgenerated.h"
#include "gimpmarshal.h"
#include "gimptagged.h"
@@ -126,9 +126,9 @@
klass->select_brush = gimp_brush_real_select_brush;
klass->want_null_motion = gimp_brush_real_want_null_motion;
- klass->scale_size = gimp_brush_real_scale_size;
- klass->scale_mask = gimp_brush_real_scale_mask;
- klass->scale_pixmap = gimp_brush_real_scale_pixmap;
+ klass->transform_size = gimp_brush_real_transform_size;
+ klass->transform_mask = gimp_brush_real_transform_mask;
+ klass->transform_pixmap = gimp_brush_real_transform_pixmap;
klass->spacing_changed = NULL;
g_object_class_install_property (object_class, PROP_SPACING,
@@ -276,13 +276,13 @@
if (scale != 1.0)
{
- mask_buf = gimp_brush_scale_mask (brush, scale);
+ mask_buf = gimp_brush_transform_mask (brush, scale);
if (! mask_buf)
mask_buf = temp_buf_new (1, 1, 1, 0, 0, transp);
if (pixmap_buf)
- pixmap_buf = gimp_brush_scale_pixmap (brush, scale);
+ pixmap_buf = gimp_brush_transform_pixmap (brush, scale);
mask_width = mask_buf->width;
mask_height = mask_buf->height;
@@ -456,10 +456,10 @@
}
void
-gimp_brush_scale_size (GimpBrush *brush,
- gdouble scale,
- gint *width,
- gint *height)
+gimp_brush_transform_size (GimpBrush *brush,
+ gdouble scale,
+ gint *width,
+ gint *height)
{
g_return_if_fail (GIMP_IS_BRUSH (brush));
g_return_if_fail (scale > 0.0);
@@ -474,12 +474,12 @@
return;
}
- GIMP_BRUSH_GET_CLASS (brush)->scale_size (brush, scale, width, height);
+ GIMP_BRUSH_GET_CLASS (brush)->transform_size (brush, scale, width, height);
}
TempBuf *
-gimp_brush_scale_mask (GimpBrush *brush,
- gdouble scale)
+gimp_brush_transform_mask (GimpBrush *brush,
+ gdouble scale)
{
g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
g_return_val_if_fail (scale > 0.0, NULL);
@@ -487,12 +487,12 @@
if (scale == 1.0)
return temp_buf_copy (brush->mask, NULL);
- return GIMP_BRUSH_GET_CLASS (brush)->scale_mask (brush, scale);
+ return GIMP_BRUSH_GET_CLASS (brush)->transform_mask (brush, scale);
}
TempBuf *
-gimp_brush_scale_pixmap (GimpBrush *brush,
- gdouble scale)
+gimp_brush_transform_pixmap (GimpBrush *brush,
+ gdouble scale)
{
g_return_val_if_fail (GIMP_IS_BRUSH (brush), NULL);
g_return_val_if_fail (brush->pixmap != NULL, NULL);
@@ -501,7 +501,7 @@
if (scale == 1.0)
return temp_buf_copy (brush->pixmap, NULL);
- return GIMP_BRUSH_GET_CLASS (brush)->scale_pixmap (brush, scale);
+ return GIMP_BRUSH_GET_CLASS (brush)->transform_pixmap (brush, scale);
}
TempBuf *
Modified: trunk/app/core/gimpbrush.h
==============================================================================
--- trunk/app/core/gimpbrush.h (original)
+++ trunk/app/core/gimpbrush.h Sun Feb 1 11:08:22 2009
@@ -56,13 +56,13 @@
gboolean (* want_null_motion) (GimpBrush *brush,
GimpCoords *last_coords,
GimpCoords *cur_coords);
- void (* scale_size) (GimpBrush *brush,
+ void (* transform_size) (GimpBrush *brush,
gdouble scale,
gint *width,
gint *height);
- TempBuf * (* scale_mask) (GimpBrush *brush,
+ TempBuf * (* transform_mask) (GimpBrush *brush,
gdouble scale);
- TempBuf * (* scale_pixmap) (GimpBrush *brush,
+ TempBuf * (* transform_pixmap) (GimpBrush *brush,
gdouble scale);
/* signals */
@@ -82,14 +82,14 @@
GimpCoords *last_coords,
GimpCoords *cur_coords);
-/* Gets width and height of a scaled mask of the brush, for provided scale. */
-void gimp_brush_scale_size (GimpBrush *brush,
+/* Gets width and height of a transformed mask of the brush, for provided parameters. */
+void gimp_brush_transform_size (GimpBrush *brush,
gdouble scale,
gint *width,
gint *height);
-TempBuf * gimp_brush_scale_mask (GimpBrush *brush,
+TempBuf * gimp_brush_transform_mask (GimpBrush *brush,
gdouble scale);
-TempBuf * gimp_brush_scale_pixmap (GimpBrush *brush,
+TempBuf * gimp_brush_transform_pixmap (GimpBrush *brush,
gdouble scale);
TempBuf * gimp_brush_get_mask (const GimpBrush *brush);
Modified: trunk/app/core/gimpbrushgenerated.c
==============================================================================
--- trunk/app/core/gimpbrushgenerated.c (original)
+++ trunk/app/core/gimpbrushgenerated.c Sun Feb 1 11:08:22 2009
@@ -63,11 +63,11 @@
static const gchar * gimp_brush_generated_get_extension (GimpData *data);
static GimpData * gimp_brush_generated_duplicate (GimpData *data);
-static void gimp_brush_generated_scale_size (GimpBrush *gbrush,
+static void gimp_brush_generated_transform_size(GimpBrush *gbrush,
gdouble scale,
gint *width,
gint *height);
-static TempBuf * gimp_brush_generated_scale_mask (GimpBrush *gbrush,
+static TempBuf * gimp_brush_generated_transform_mask(GimpBrush *gbrush,
gdouble scale);
static TempBuf * gimp_brush_generated_calc (GimpBrushGenerated *brush,
@@ -106,16 +106,16 @@
GimpDataClass *data_class = GIMP_DATA_CLASS (klass);
GimpBrushClass *brush_class = GIMP_BRUSH_CLASS (klass);
- object_class->set_property = gimp_brush_generated_set_property;
- object_class->get_property = gimp_brush_generated_get_property;
+ object_class->set_property = gimp_brush_generated_set_property;
+ object_class->get_property = gimp_brush_generated_get_property;
- data_class->save = gimp_brush_generated_save;
- data_class->dirty = gimp_brush_generated_dirty;
- data_class->get_extension = gimp_brush_generated_get_extension;
- data_class->duplicate = gimp_brush_generated_duplicate;
+ data_class->save = gimp_brush_generated_save;
+ data_class->dirty = gimp_brush_generated_dirty;
+ data_class->get_extension = gimp_brush_generated_get_extension;
+ data_class->duplicate = gimp_brush_generated_duplicate;
- brush_class->scale_size = gimp_brush_generated_scale_size;
- brush_class->scale_mask = gimp_brush_generated_scale_mask;
+ brush_class->transform_size = gimp_brush_generated_transform_size;
+ brush_class->transform_mask = gimp_brush_generated_transform_mask;
g_object_class_install_property (object_class, PROP_SHAPE,
g_param_spec_enum ("shape", NULL, NULL,
@@ -277,10 +277,10 @@
}
static void
-gimp_brush_generated_scale_size (GimpBrush *gbrush,
- gdouble scale,
- gint *width,
- gint *height)
+gimp_brush_generated_transform_size (GimpBrush *gbrush,
+ gdouble scale,
+ gint *width,
+ gint *height)
{
GimpBrushGenerated *brush = GIMP_BRUSH_GENERATED (gbrush);
gint half_width;
@@ -301,8 +301,8 @@
}
static TempBuf *
-gimp_brush_generated_scale_mask (GimpBrush *gbrush,
- gdouble scale)
+gimp_brush_generated_transform_mask (GimpBrush *gbrush,
+ gdouble scale)
{
GimpBrushGenerated *brush = GIMP_BRUSH_GENERATED (gbrush);
@@ -498,7 +498,7 @@
return mask;
}
-/* This function is shared between gimp_brush_generated_scale_size and
+/* This function is shared between gimp_brush_generated_transform_size and
* gimp_brush_generated_calc, therefore we provide a bunch of optional
* pointers for returnvalues.
*/
Modified: trunk/app/paint/gimpbrushcore.c
==============================================================================
--- trunk/app/paint/gimpbrushcore.c (original)
+++ trunk/app/paint/gimpbrushcore.c Sun Feb 1 11:08:22 2009
@@ -101,9 +101,9 @@
gdouble y);
static gdouble gimp_brush_core_clamp_brush_scale (GimpBrushCore *core,
gdouble scale);
-static TempBuf * gimp_brush_core_scale_mask (GimpBrushCore *core,
+static TempBuf * gimp_brush_core_transform_mask (GimpBrushCore *core,
GimpBrush *brush);
-static TempBuf * gimp_brush_core_scale_pixmap (GimpBrushCore *core,
+static TempBuf * gimp_brush_core_transform_pixmap (GimpBrushCore *core,
GimpBrush *brush);
static void gimp_brush_core_invalidate_cache (GimpBrush *brush,
@@ -164,30 +164,44 @@
{
gint i, j;
- core->main_brush = NULL;
- core->brush = NULL;
- core->spacing = 1.0;
- core->scale = 1.0;
-
- core->pressure_brush = NULL;
+ core->main_brush = NULL;
+ core->brush = NULL;
+ core->spacing = 1.0;
+ core->scale = 1.0;
+
+ core->pressure_brush = NULL;
+
+ core->last_solid_brush = NULL;
+ core->solid_cache_invalid = FALSE;
+
+ core->transform_brush = NULL;
+ core->last_transform_brush = NULL;
+ core->last_transform_width = 0;
+ core->last_transform_height = 0;
+ core->last_scale = 1.0;
+
+ core->transform_pixmap = NULL;
+ core->last_transform_pixmap = NULL;
+ core->last_transform_pixmap_width = 0;
+ core->last_transform_pixmap_height = 0;
+
+ core->last_brush_mask = NULL;
+ core->cache_invalid = FALSE;
+
+ core->rand = g_rand_new ();
+
+ core->brush_bound_segs = NULL;
+ core->n_brush_bound_segs = 0;
+ core->brush_bound_width = 0;
+ core->brush_bound_height = 0;
for (i = 0; i < BRUSH_CORE_SOLID_SUBSAMPLE; i++)
- for (j = 0; j < BRUSH_CORE_SOLID_SUBSAMPLE; j++)
- core->solid_brushes[i][j] = NULL;
-
- core->last_solid_brush = NULL;
- core->solid_cache_invalid = FALSE;
-
- core->scale_brush = NULL;
- core->last_scale_brush = NULL;
- core->last_scale_width = 0;
- core->last_scale_height = 0;
- core->last_scale = 1.0;
-
- core->scale_pixmap = NULL;
- core->last_scale_pixmap = NULL;
- core->last_scale_pixmap_width = 0;
- core->last_scale_pixmap_height = 0;
+ {
+ for (j = 0; j < BRUSH_CORE_SOLID_SUBSAMPLE; j++)
+ {
+ core->solid_brushes[i][j] = NULL;
+ }
+ }
for (i = 0; i < BRUSH_CORE_JITTER_LUTSIZE - 1; ++i)
{
@@ -200,18 +214,13 @@
g_assert (BRUSH_CORE_SUBSAMPLE == KERNEL_SUBSAMPLE);
for (i = 0; i < KERNEL_SUBSAMPLE + 1; i++)
- for (j = 0; j < KERNEL_SUBSAMPLE + 1; j++)
- core->kernel_brushes[i][j] = NULL;
-
- core->last_brush_mask = NULL;
- core->cache_invalid = FALSE;
-
- core->rand = g_rand_new ();
+ {
+ for (j = 0; j < KERNEL_SUBSAMPLE + 1; j++)
+ {
+ core->kernel_brushes[i][j] = NULL;
+ }
+ }
- core->brush_bound_segs = NULL;
- core->n_brush_bound_segs = 0;
- core->brush_bound_width = 0;
- core->brush_bound_height = 0;
}
static void
@@ -234,16 +243,16 @@
core->solid_brushes[i][j] = NULL;
}
- if (core->scale_brush)
+ if (core->transform_brush)
{
- temp_buf_free (core->scale_brush);
- core->scale_brush = NULL;
+ temp_buf_free (core->transform_brush);
+ core->transform_brush = NULL;
}
- if (core->scale_pixmap)
+ if (core->transform_pixmap)
{
- temp_buf_free (core->scale_pixmap);
- core->scale_pixmap = NULL;
+ temp_buf_free (core->transform_pixmap);
+ core->transform_pixmap = NULL;
}
if (core->rand)
@@ -694,7 +703,7 @@
core->scale = gimp_brush_core_clamp_brush_scale (core, core->scale);
- gimp_brush_scale_size (core->brush, core->scale, &brush_width, &brush_height);
+ gimp_brush_transform_size (core->brush, core->scale, &brush_width, &brush_height);
/* adjust the x and y coordinates to the upper left corner of the brush */
x = (gint) floor (paint_core->cur_coords.x) - (brush_width / 2);
@@ -785,7 +794,7 @@
{
scale = gimp_brush_core_clamp_brush_scale (core, scale);
- mask = gimp_brush_scale_mask (core->main_brush, scale);
+ mask = gimp_brush_transform_mask (core->main_brush, scale);
}
if (mask)
@@ -1278,8 +1287,8 @@
}
static TempBuf *
-gimp_brush_core_scale_mask (GimpBrushCore *core,
- GimpBrush *brush)
+gimp_brush_core_transform_mask (GimpBrushCore *core,
+ GimpBrush *brush)
{
gint width;
gint height;
@@ -1290,36 +1299,36 @@
if (core->scale == 1.0)
return brush->mask;
- gimp_brush_scale_size (brush, core->scale, &width, &height);
+ gimp_brush_transform_size (brush, core->scale, &width, &height);
- if (! core->cache_invalid &&
- core->scale_brush &&
- brush->mask == core->last_scale_brush &&
- width == core->last_scale_width &&
- height == core->last_scale_height &&
+ if (! core->cache_invalid &&
+ core->transform_brush &&
+ brush->mask == core->last_transform_brush &&
+ width == core->last_transform_width &&
+ height == core->last_transform_height &&
core->scale == core->last_scale)
{
- return core->scale_brush;
+ return core->transform_brush;
}
- core->last_scale_brush = brush->mask;
- core->last_scale_width = width;
- core->last_scale_height = height;
+ core->last_transform_brush = brush->mask;
+ core->last_transform_width = width;
+ core->last_transform_height = height;
core->last_scale = core->scale;
- if (core->scale_brush)
- temp_buf_free (core->scale_brush);
+ if (core->transform_brush)
+ temp_buf_free (core->transform_brush);
- core->scale_brush = gimp_brush_scale_mask (brush, core->scale);
+ core->transform_brush = gimp_brush_transform_mask (brush, core->scale);
core->cache_invalid = TRUE;
core->solid_cache_invalid = TRUE;
- return core->scale_brush;
+ return core->transform_brush;
}
static TempBuf *
-gimp_brush_core_scale_pixmap (GimpBrushCore *core,
+gimp_brush_core_transform_pixmap (GimpBrushCore *core,
GimpBrush *brush)
{
gint width;
@@ -1331,29 +1340,29 @@
if (core->scale == 1.0)
return brush->pixmap;
- gimp_brush_scale_size (brush, core->scale, &width, &height);
+ gimp_brush_transform_size (brush, core->scale, &width, &height);
- if (! core->cache_invalid &&
- core->scale_pixmap &&
- brush->pixmap == core->last_scale_pixmap &&
- width == core->last_scale_pixmap_width &&
- height == core->last_scale_pixmap_height)
+ if (! core->cache_invalid &&
+ core->transform_pixmap &&
+ brush->pixmap == core->last_transform_pixmap &&
+ width == core->last_transform_pixmap_width &&
+ height == core->last_transform_pixmap_height)
{
- return core->scale_pixmap;
+ return core->transform_pixmap;
}
- core->last_scale_pixmap = brush->pixmap;
- core->last_scale_pixmap_width = width;
- core->last_scale_pixmap_height = height;
+ core->last_transform_pixmap = brush->pixmap;
+ core->last_transform_pixmap_width = width;
+ core->last_transform_pixmap_height = height;
- if (core->scale_pixmap)
- temp_buf_free (core->scale_pixmap);
+ if (core->transform_pixmap)
+ temp_buf_free (core->transform_pixmap);
- core->scale_pixmap = gimp_brush_scale_pixmap (brush, core->scale);
+ core->transform_pixmap = gimp_brush_transform_pixmap (brush, core->scale);
core->cache_invalid = TRUE;
- return core->scale_pixmap;
+ return core->transform_pixmap;
}
TempBuf *
@@ -1364,7 +1373,7 @@
GimpPaintCore *paint_core = GIMP_PAINT_CORE (core);
TempBuf *mask;
- mask = gimp_brush_core_scale_mask (core, core->brush);
+ mask = gimp_brush_core_transform_mask (core, core->brush);
if (! mask)
return NULL;
@@ -1429,13 +1438,13 @@
image = gimp_item_get_image (GIMP_ITEM (drawable));
/* scale the brushes */
- pixmap_mask = gimp_brush_core_scale_pixmap (core, core->brush);
+ pixmap_mask = gimp_brush_core_transform_pixmap (core, core->brush);
if (! pixmap_mask)
return;
if (mode != GIMP_BRUSH_HARD)
- brush_mask = gimp_brush_core_scale_mask (core, core->brush);
+ brush_mask = gimp_brush_core_transform_mask (core, core->brush);
else
brush_mask = NULL;
Modified: trunk/app/paint/gimpbrushcore.h
==============================================================================
--- trunk/app/paint/gimpbrushcore.h (original)
+++ trunk/app/paint/gimpbrushcore.h Sun Feb 1 11:08:22 2009
@@ -53,16 +53,16 @@
TempBuf *last_solid_brush;
gboolean solid_cache_invalid;
- TempBuf *scale_brush;
- TempBuf *last_scale_brush;
- gint last_scale_width;
- gint last_scale_height;
+ TempBuf *transform_brush;
+ TempBuf *last_transform_brush;
+ gint last_transform_width;
+ gint last_transform_height;
gdouble last_scale;
- TempBuf *scale_pixmap;
- TempBuf *last_scale_pixmap;
- gint last_scale_pixmap_width;
- gint last_scale_pixmap_height;
+ TempBuf *transform_pixmap;
+ TempBuf *last_transform_pixmap;
+ gint last_transform_pixmap_width;
+ gint last_transform_pixmap_height;
TempBuf *kernel_brushes[BRUSH_CORE_SUBSAMPLE + 1][BRUSH_CORE_SUBSAMPLE + 1];
Modified: trunk/app/paint/gimpsmudge.c
==============================================================================
--- trunk/app/paint/gimpsmudge.c (original)
+++ trunk/app/paint/gimpsmudge.c Sun Feb 1 11:08:22 2009
@@ -328,8 +328,8 @@
gint width;
gint height;
- gimp_brush_scale_size (brush_core->brush, brush_core->scale,
- &width, &height);
+ gimp_brush_transform_size (brush_core->brush, brush_core->scale,
+ &width, &height);
/* Note: these are the brush mask size plus a border of 1 pixel */
*x = (gint) paint_core->cur_coords.x - width / 2 - 1;
[
Date Prev][
Date Next] [
Thread Prev][
Thread Next]
[
Thread Index]
[
Date Index]
[
Author Index]
--- /trunk/app/core/gimpbrush-scale.c (original)
+++ trunk/app/core/gimpbrush-transform.c Sun Feb 1 11:08:22 2009
@@ -24,7 +24,7 @@
#include "core-types.h"
#include "gimpbrush.h"
-#include "gimpbrush-scale.h"
+#include "gimpbrush-transform.h"
#include "base/pixel-region.h"
#include "base/temp-buf.h"
@@ -48,30 +48,30 @@
/* public functions */
void
-gimp_brush_real_scale_size (GimpBrush *brush,
- gdouble scale,
- gint *width,
- gint *height)
+gimp_brush_real_transform_size (GimpBrush *brush,
+ gdouble scale,
+ gint *width,
+ gint *height)
{
*width = (gint) (brush->mask->width * scale + 0.5);
*height = (gint) (brush->mask->height * scale + 0.5);
}
TempBuf *
-gimp_brush_real_scale_mask (GimpBrush *brush,
- gdouble scale)
+gimp_brush_real_transform_mask (GimpBrush *brush,
+ gdouble scale)
{
gint dest_width;
gint dest_height;
- gimp_brush_scale_size (brush, scale, &dest_width, &dest_height);
+ gimp_brush_transform_size (brush, scale, &dest_width, &dest_height);
if (dest_width <= 0 || dest_height <= 0)
return NULL;
if (scale <= 1.0)
{
/* Downscaling with brush_scale_mask is much faster than with
* gimp_brush_scale_buf.
*/
return gimp_brush_scale_mask_down (brush->mask,
@@ -82,13 +82,13 @@
}
TempBuf *
-gimp_brush_real_scale_pixmap (GimpBrush *brush,
- gdouble scale)
+gimp_brush_real_transform_pixmap (GimpBrush *brush,
+ gdouble scale)
{
gint dest_width;
gint dest_height;
- gimp_brush_scale_size (brush, scale, &dest_width, &dest_height);
+ gimp_brush_transform_size (brush, scale, &dest_width, &dest_height);
if (dest_width <= 0 || dest_height <= 0)
return NULL;
Copied: trunk/app/core/gimpbrush-transform.h (from r27974, /trunk/app/core/gimpbrush-scale.h)
@@ -48,30 +48,30 @@
if (scale <= 1.0)
{
- /* Downscaling with brush_scale_mask is much faster than with
+ /* Downscaling with brush_transform_mask is much faster than with
* gimp_brush_scale_buf.
*/
==============================================================================